@@ -15,9 +15,7 @@
 
 #include <irda.h>
 
-int fd;
-
-int ias_query(char *class, char *attrib)
+int ias_query(int fd, int daddr, char *class, char *attrib)
 {
 	struct irda_ias_set query;
 	int len;
@@ -28,6 +26,8 @@ int ias_query(char *class, char *attrib)
 
 	strncpy(query.irda_class_name, class, IAS_MAX_CLASSNAME);
 	strncpy(query.irda_attrib_name, attrib, IAS_MAX_ATTRIBNAME);
+	if(daddr)
+		query.daddr = daddr;
 
 	if (getsockopt(fd, SOL_IRLMP, IRLMP_IAS_QUERY, &query, &len)) {
 		perror("getsockopt");
@@ -68,13 +68,26 @@ int ias_query(char *class, char *attrib)
  */
 int main(int argc, char *argv[])
 {
+	int fd;
+	int iraddr;
+
 	/* Create socket */
 	fd = socket(AF_IRDA, SOCK_STREAM, 0);
 	if (fd < 0) {
 		perror("socket");
 		exit(-1);
         }
-	ias_query(argv[1], argv[2]);
+	/* Check args */
+	if(argc < 4) {
+		fprintf(stderr, "Usage : %s iraddr class attrib\n", argv[0]);
+		return 0;
+	}
+	/* Convert IrDA address to binary */
+	if(sscanf(argv[1], "%X", &iraddr) != 1) {
+		fprintf(stderr, "Invalid address: \"%s\"...\n", argv[1]);
+		return 0;
+	}
+	ias_query(fd, iraddr, argv[2], argv[3]);
 
 	return 0;
 }
