@@ -118,7 +118,7 @@ int two = 0;		/* Open only one client sockets (1 = two) */
  */
 void irdaspray_sethintmask(int fd)
 {
-	int hints;
+	unsigned char	hints[4];
 
 	/*
 	 * The hint mask we use is set to catch any device that potentially
@@ -127,11 +127,12 @@ void irdaspray_sethintmask(int fd)
 	 * Setting the hint mask with IrComm or IrObex could be usefull
 	 * for some apps...
 	 */
-	hints = HINT_COMPUTER | HINT_PDA;
+	hints[0] = HINT_COMPUTER | HINT_PDA;
+	hints[1] = 0;
 
 	/* Set the filter used for performing discovery */
-	if (setsockopt(fd, SOL_IRLMP, IRLMP_HINT_MASK_SET, &hints, 
-		       sizeof(hints))) 
+	if (setsockopt(fd, SOL_IRLMP, IRLMP_HINT_MASK_SET,
+		       hints, sizeof(hints))) 
 	{
 		perror("setsockopt");
 		exit(-1);
@@ -694,29 +695,32 @@ int ir_client(void)
 	}
 
 	if (echo) {
-		/* Fork off receiver */
+		/* Fork off transmitter */
 		pid = fork();
 		
-		if (pid) {
+		if (pid) {	/* parent */
 			total = irdaspray_receive(fd);
-		} else {
+		} else {	/* child */
 			total = irdaspray_transmit(fd);
 		}
-	} else
+	} else			/* single */
 		total = irdaspray_transmit(fd);
 
+	/* pid==0: single-thread(discard-tx) or child(echo-tx)
+	 * pid!=0: parent(echo-rx)
+	 */
+
 	gettimeofday(&end, (struct timezone*) 0);
 
 	time = (double) (end.tv_sec - start.tv_sec) + (double)
 		((double) (end.tv_usec - start.tv_usec) / 1000000.0);
 
-	if (pid) 
+	if (pid) {	/* parent */
+		wait(&status);
 		printf("Received %d bytes in %f seconds (%0.3f kbytes/s)\n",
 		       total, time, (double) (total / time) / 1024); 
-	else {
-		if (echo)
-			wait(&status);
-		
+	}
+	else {		/* child or single-thread */
 		printf("Transmitted %d bytes in %f seconds (%0.3f kbytes/s)\n",
 		       total, time, (double) (total / time) / 1024);
 	}
@@ -782,6 +786,11 @@ int ir_server(void)
 		addrlen = sizeof(struct sockaddr_irda);
 
 		printf("Waiting for connection!\n");
+
+		/* collect old server zombies */
+		while (waitpid(-1, NULL, WNOHANG) > 0)
+			;
+
 		conn_fd = accept(fd, (struct sockaddr *) &peer, &addrlen);
 		if (conn_fd < 0) {
 			perror("accept");
